@@ -1,107 +1,21 @@
-=head1 NAME
-
-Clustericious::Config - configuration files for Clustericious nodes.
-
-=head1 SYNOPSIS
-
- $ cat > ~/etc/MyApp.conf
- ---
- % extends_config 'global';
- % extends_config 'hypnotoad', url => 'http://localhost:9999', app => 'MyApp';
-
- url : http://localhost:9999
- start_mode : hypnotoad
- hypnotoad :
-    - heartbeat_timeout : 500
-
- $ cat > ~/global.conf
- ---
- somevar : somevalue
-
- $ cat > ~/hypnotoad.conf
- listen :
-    - <%= $url %>
- pid_file : <%= $ENV{HOME} %>/<%= $app %>/hypnotoad.pid
- env :
-    MOJO_HOME : <%= $ENV{HOME} %>/<%= $app %>
-
-Then later in a program somewhere :
-
- my $c = Clustericious::Config->new("MyApp");
- my $c = Clustericious::Config->new( \$config_string );
- my $c = Clustericious::Config->new( \%config_data_structure );
-
- print $c->url;
- print $c->{url};
-
- print $c->hypnotoad->listen;
- print $c->hypnotoad->{listen};
- my %hash = $c->hypnotoad;
- my @ary  = $c->hypnotoad;
-
- # Supply a default value for a missing configuration parameter :
- $c->url(default => "http://localhost:9999");
- print $c->this_param_is_missing(default => "something_else");
-
- # Dump out the entire config as yaml
- print $c->dump_as_yaml;
-
-=head1 DESCRIPTION
-
-Clustericious::Config reads configuration files which are Mojo::Template's
-of JSON or YAML files.  There should generally be an entry for
-'url', which may be used by either a client or a server depending on
-how this node in the cluster is being used.
-
-After rendering the template and parsing the JSON, the resulting
-object may be called using method calls or treated as hashes.
-
-Config files are looked for in the following places (in order, where
-"MyApp" is the name of the app) :
-
-    $CLUSTERICIOUS_CONF_DIR/MyApp.conf
-    $HOME/etc/MyApp.conf
-    /util/etc/MyApp.conf
-    /etc/MyApp.conf
-
-The helper "extends_config" may be used to read default settings
-from another config file.  The first argument to extends_config is the
-basename of the config file.  Additional named arguments may be passed
-to that config file and used as variables within that file.  After
-reading another file, the hashes are merged (i.e. with Hash::Merge);
-so values anywhere inside the datastructure may be overridden.
-
-YAML config files must begin with "---", otherwise they are interpreted
-as JSON.
-
-Clustericious::Config provides a "get_password" function which will prompt
-for a password if it is needed.  It can be used like this :
-
- password : <%= get_password =%>
-
-This will prompt the user the first time it is encountered.
-
-=head1 METHODS
-
-=cut
-
 package Clustericious::Config;
 
-use Clustericious::Config::Password;
-
 use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.23';
+# ABSTRACT: configuration files for Clustericious nodes.
+our $VERSION = '0.25'; # VERSION
 
+
+use Clustericious::Config::Password;
 use List::Util;
 use JSON::XS;
 use YAML::XS ();
 use Mojo::Template;
 use Log::Log4perl qw/:easy/;
 use Storable;
-use Clustericious::Config::Plugin;
+use Clustericious::Config::Helpers ();
 use Data::Dumper;
 use Cwd ();
 use Module::Build;
@@ -134,12 +48,6 @@ sub _uncache {
 sub pre_rendered { }
 sub rendered { }
 
-=head2 new
-
-Create a new Clustericious::Config object.  See the SYPNOSIS for
-possible invocations.
-
-=cut
 
 sub new {
     my $class = shift;
@@ -163,7 +71,7 @@ sub new {
     
     state $package_counter = 0;
     my $namespace = "Clustericious::Config::TemplatePackage::Package$package_counter";
-    eval qq{ package $namespace; use Clustericious::Config::Plugin; };
+    eval qq{ package $namespace; use Clustericious::Config::Helpers; };
     die $@ if $@;
     $package_counter++;
     
@@ -222,7 +130,7 @@ sub new {
         }
     }
     $conf_data ||= {};
-    Clustericious::Config::Plugin->do_merges($conf_data);
+    Clustericious::Config::Helpers->_do_merges($conf_data);
     _add_heuristics($filename,$conf_data);
     # Use derived classes so that AUTOLOADING keeps namespaces separate
     # for various apps.
@@ -252,6 +160,7 @@ sub _add_heuristics {
 
 }
 
+
 sub dump_as_yaml {
     my $c = shift;
     return YAML::XS::Dump($c);
@@ -303,13 +212,6 @@ sub AUTOLOAD {
     $self->$called;
 }
 
-=head2 set_singleton
-
-Clustericicious::Config->set_singleton(App => $object);
-
-Cache a config object to be returned by the constructor.
-
-=cut
 
 sub set_singleton {
     my $class = shift;
@@ -319,41 +221,185 @@ sub set_singleton {
     $Singletons{$app} = $obj;
 }
 
+
+1;
+
+
+__END__
+=pod
+
+=head1 NAME
+
+Clustericious::Config - configuration files for Clustericious nodes.
+
+=head1 VERSION
+
+version 0.25
+
+=head1 SYNOPSIS
+
+In your ~/etc/MyApp.conf file:
+
+ ---
+ % extends_config 'global';
+ % extends_config 'hypnotoad', url => 'http://localhost:9999', app => 'MyApp';
+
+ url : http://localhost:9999
+ start_mode : hypnotoad
+ hypnotoad :
+    - heartbeat_timeout : 500
+ 
+ arbitrary_key: value
+
+In your ~/etc/globa.conf file:
+
+ ---
+ somevar : somevalue
+
+In your ~/etc/hypnotoad.conf:
+
+ listen :
+    - <%= $url %>
+ # home uses File::HomeDir to find the calling users'
+ # home directory
+ pid_file : <%= home %>/<%= $app %>/hypnotoad.pid
+ env :
+    MOJO_HOME : <%= home %>/<%= $app %>
+
+From a L<Clustericious::App>:
+
+ package MyApp;
+ 
+ use Mojo::Base qw( Clustericious::App );
+ 
+ package MyApp::Routes;
+ 
+ use Clustericious::RouteBuilder;
+ 
+ get '/' => sub {
+   my $c = shift;
+   my $config = $c; # $config isa Clustericious::Config
+   
+   # returns the value if it is defined, foo otherwise
+   my $value = $config->arbitrary_key(default => 'foo');
+ };
+
+From a script:
+
+ use Clustericious::Config;
+ 
+ my $c = Clustericious::Config->new("MyApp");
+ my $c = Clustericious::Config->new( \$config_string );
+ my $c = Clustericious::Config->new( \%config_data_structure );
+
+ print $c->url;
+ print $c->{url};
+
+ print $c->hypnotoad->listen;
+ print $c->hypnotoad->{listen};
+ my %hash = $c->hypnotoad;
+ my @ary  = $c->hypnotoad;
+
+ # Supply a default value for a missing configuration parameter :
+ $c->url(default => "http://localhost:9999");
+ print $c->this_param_is_missing(default => "something_else");
+
+ # Dump out the entire config as yaml
+ print $c->dump_as_yaml;
+
+=head1 DESCRIPTION
+
+Clustericious::Config reads configuration files which are Mojo::Template's
+of JSON or YAML files.  There should generally be an entry for
+'url', which may be used by either a client or a server depending on
+how this node in the cluster is being used.
+
+After rendering the template and parsing the JSON, the resulting
+object may be called using method calls or treated as hashes.
+
+Config files are looked for in the following places (in order, where
+"MyApp" is the name of the app) :
+
+    $CLUSTERICIOUS_CONF_DIR/MyApp.conf
+    $HOME/etc/MyApp.conf
+    /util/etc/MyApp.conf
+    /etc/MyApp.conf
+
+The helper "extends_config" may be used to read default settings
+from another config file.  The first argument to extends_config is the
+basename of the config file.  Additional named arguments may be passed
+to that config file and used as variables within that file.  After
+reading another file, the hashes are merged (i.e. with Hash::Merge);
+so values anywhere inside the data structure may be overridden.
+
+YAML config files must begin with "---", otherwise they are interpreted
+as JSON.
+
+This module provides a number of helpers
+which can be used to get system details (such as the home directory of
+the calling user or to prompt for passwords).  See L<Clustericious::Config::Helpers>
+for details.
+
+=head1 CONSTRUCTOR
+
+=head2 new
+
+Create a new Clustericious::Config object.  See the SYNOPSIS for
+possible invocations.
+
+=head1 METHODS
+
+=head2 $config-E<gt>dump_as_yaml
+
+Returns a string with the configuration encoded as YAML.
+
+=head2 Clustericious::Config->set_singleton
+
+Cache a config object to be returned by the constructor.  Usage:
+
+ Clustericicious::Config->set_singleton(App => $object);
+
 =head1 ENVIRONMENT
 
 If the environment variable HARNESS_ACTIVE is set,
 and the current module::build object tells us that
 the calling module is being tested, then an empty
 configuration is used.  In this situation, however,
-if $ENV{CLUSTERICIOUS_CONF_DIR} is set and if it
-is a subdirectory of the current directory, then
-it will be used.  This allows unit tests to provide
-configuration directories, but avoids using configurations
-that are outside of the build tree during unit testing.
+if the CLUSTERICIOUS_CONF_DIR environment variable
+is set and if it is a subdirectory of the current 
+directory, then it will be used.  This allows unit 
+tests to provide configuration directories, but 
+avoids using configurations that are outside of 
+the build tree during unit testing.
 
 =head1 CAVEATS
 
-Some filesystems do not support filenames with a colen
-(:) character in them, so for apps with a double colen
+Some filesystems do not support filenames with a colon
+(:) character in them, so for apps with a double colon
 in them (for example L<Clustericious::HelloWorld>),
 a single dash character will be substituted for the name
 (for example C<Clustericious-HelloWorld.conf>).
 
-=head1 AUTHORS
-
-Brian Duggan
-
-Graham Ollis <gollis@sesda3.com>
-
 =head1 NOTES
 
 This is a beta release. The API may change without notice.
 
 =head1 SEE ALSO
 
-L<Mojo::Template>, L<Hash::Merge>, L<Clustericious>, L<Clustericious::Client>
+L<Mojo::Template>, L<Hash::Merge>, L<Clustericious>, L<Clustericious::Client>, L<Clustericious::Config::Helpers>
+
+=head1 AUTHOR
+
+original author: Brian Duggan
+
+current maintainer: Graham Ollis <plicease@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by NASA GSFC.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
-
